module mi_vga(clk,h_sync,v_sync,video_on,x_pixel,y_pixel);

parameter N=11;
input clk;
output h_sync;
output v_sync;
output video_on;
output [N-1:0]x_pixel;
output [N-1:0]y_pixel;

reg [N-1:0]x_counter;
reg [N-1:0]y_counter;

localparam HD = 640;		// horizontal display area
localparam HF = 48; 		// h front left border
localparam HB = 16;		// h back right border
localparam HR = 96; 		// h retrace
localparam VD = 480;		// vertical display area
localparam VF = 10;		// v front top  border
localparam VB = 33;		// v back bottom  border
localparam VR = 2;		// v retrace

always@(posedge clk)
begin
	y_counter<=y_counter;
	if(x_counter>=(HD+HF+HB+HR-1)) 
	begin
		x_counter<=0;
		if(y_counter>=(VD+VF+VB+VR-1))
		begin
			y_counter<=0;
		end
		else
		begin
			y_counter<=y_counter+1'b1;
		end
	end
	else 
	begin
		x_counter<=x_counter+1'b1;
	end
end

reg h_sync_reg;
reg v_sync_reg;

always@(posedge clk)
begin
	h_sync_reg<= (x_counter>=(HD+HB)) && (x_counter<=(HD+HB+HR-1));
	v_sync_reg<= (y_counter>=(VD+VB)) && (y_counter<=(VD+VB+VR-1));
end
assign h_sync=h_sync_reg;
assign v_sync=v_sync_reg;
assign video_on=(x_counter<(HD)) &&	(y_counter<(VD));

assign x_pixel=x_counter;
assign y_pixel=y_counter;

endmodule